@@ -45,7 +45,7 @@ def convert_py_float_to_cffi( x):
 
 
 def convert_py_int_to_cffi( x):
-    x = x.astype( np.intc)
+    x = np.intc( x)
     px = np.array( x)
     pxcffi = ffi.cast( "int *", px.ctypes.data)
     return px, pxcffi
@@ -222,23 +222,25 @@ def IsElementC(i, j, env):
 
 # Generated python wrapper for:
 #    void py_ExpandKinteractive2Bit(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize)
-def ExpandKinteractive2Bit(src, env, kint, arraysize):
+def ExpandKinteractive2Bit(src, env, kint):
     trace( "void py_ExpandKinteractive2Bit(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize)")
     pout_destnp, pout_dest = create_float_zeros_as_CFFI_double( env.m)
     psrcnp, psrc = convert_py_float_to_cffi( src)
-    fm.py_ExpandKinteractive2Bit( pout_destpsrc, env, kint, arraysize)
+    arraysize = fm.py_SizeArraykinteractive( env.n, kint, env)
+    fm.py_ExpandKinteractive2Bit( pout_dest, psrc, env, kint, arraysize)
     return pout_destnp
 
 
 # Generated python wrapper for:
-#    void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* VVC)
-def ExpandKinteractive2Bit_m(src, env, kint, arraysize, VVC):
-    trace( "void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* VVC)")
+#    void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)
+def ExpandKinteractive2Bit_m(src, env, kint):
+    trace( "void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)")
     pout_destnp, pout_dest = create_float_zeros_as_CFFI_double( env.m)
+    pout_VVCnp, pout_VVC = create_float_zeros_as_CFFI_double( env.m)
     psrcnp, psrc = convert_py_float_to_cffi( src)
-    pVVCnp, pVVC = convert_py_float_to_cffi( VVC)
-    fm.py_ExpandKinteractive2Bit_m( pout_destpsrc, env, kint, arraysize, pVVC)
-    return pout_destnp
+    arraysize = fm.py_SizeArraykinteractive( env.n, kint, env)
+    fm.py_ExpandKinteractive2Bit_m( pout_dest, psrc, env, kint, arraysize, pout_VVC)
+    return pout_destnp, pout_VVCnp
 
 
 # Generated python wrapper for:
@@ -354,106 +356,116 @@ def Entropy(v, env):
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-def FuzzyMeasureFit(datanum, additive, env, dataset):
+def FuzzyMeasureFit(datanum, additive, env, dataset = None):
     trace( "void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_FuzzyMeasureFit( datanum, additive, env, pout_v, pdataset)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-def FuzzyMeasureFitMob(datanum, additive, env, dataset):
+def FuzzyMeasureFitMob(datanum, additive, env, dataset = None):
     trace( "void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_FuzzyMeasureFitMob( datanum, additive, env, pout_v, pdataset)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-def FuzzyMeasureFitKtolerant(datanum, additive, env, dataset):
+def FuzzyMeasureFitKtolerant(datanum, additive, env, dataset = None):
     trace( "void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_FuzzyMeasureFitKtolerant( datanum, additive, env, pout_v, pdataset)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-def FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset):
+def FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_FuzzyMeasureFitLPKmaxitive( datanum, additive, env, pout_v, pdataset)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
-def FuzzyMeasureFitLPKinteractive(datanum, additive, env, dataset, K):
+def FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     fm.py_FuzzyMeasureFitLPKinteractive( datanum, additive, env, pout_v, pdataset, pK)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
-def FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, dataset, K):
-    trace( "void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)")
+def FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset = None):
+    trace( "void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset = None, double* K)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     fm.py_FuzzyMeasureFitLPKinteractiveMaxChains( datanum, additive, env, pout_v, pdataset, pK)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveAutoK(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters)
-def FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, dataset, K, maxiters):
+def FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractiveAutoK(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     pmaxitersnp, pmaxiters = convert_py_int_to_cffi( maxiters)
     fm.py_FuzzyMeasureFitLPKinteractiveAutoK( datanum, additive, env, pout_v, pdataset, pK, pmaxiters)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveMarginal(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int submod)
-def FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env, dataset, K, submod):
+def FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env, K, submod, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractiveMarginal(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int submod)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     fm.py_FuzzyMeasureFitLPKinteractiveMarginal( datanum, additive, env, pout_v, pdataset, pK, submod)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)
-def FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, dataset, K, maxiters, submod):
+def FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     pmaxitersnp, pmaxiters = convert_py_int_to_cffi( maxiters)
     fm.py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain( datanum, additive, env, pout_v, pdataset, pK, pmaxiters, submod)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
-def FuzzyMeasureFitLP(datanum, additive, env, dataset, options, indexlow, indexhihg, option1, orness):
+def FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None):
     trace( "void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     poptionsnp, poptions = convert_py_int_to_cffi( options)
     pindexlownp, pindexlow = convert_py_float_to_cffi( indexlow)
@@ -461,14 +473,15 @@ def FuzzyMeasureFitLP(datanum, additive, env, dataset, options, indexlow, indexh
     poption1np, poption1 = convert_py_int_to_cffi( option1)
     pornessnp, porness = convert_py_float_to_cffi( orness)
     fm.py_FuzzyMeasureFitLP( datanum, additive, env, pout_v, pdataset, poptions, pindexlow, pindexhihg, poption1, porness)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_FuzzyMeasureFitLPMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
-def FuzzyMeasureFitLPMob(datanum, additive, env, dataset, options, indexlow, indexhihg, option1, orness):
+def FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None):
     trace( "void py_FuzzyMeasureFitLPMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     poptionsnp, poptions = convert_py_int_to_cffi( options)
     pindexlownp, pindexlow = convert_py_float_to_cffi( indexlow)
@@ -476,27 +489,29 @@ def FuzzyMeasureFitLPMob(datanum, additive, env, dataset, options, indexlow, ind
     poption1np, poption1 = convert_py_int_to_cffi( option1)
     pornessnp, porness = convert_py_float_to_cffi( orness)
     fm.py_FuzzyMeasureFitLPMob( datanum, additive, env, pout_v, pdataset, poptions, pindexlow, pindexhihg, poption1, porness)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)
-def fittingOWA(datanum, env, dataset):
+def fittingOWA(datanum, env, dataset = None):
     trace( "void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_fittingOWA( datanum, env, pout_v, pdataset)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
 #    void py_fittingWAM(int datanum, struct fm_env* env, double* out_v, double* dataset)
-def fittingWAM(datanum, env, dataset):
+def fittingWAM(datanum, env, dataset = None):
     trace( "void py_fittingWAM(int datanum, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_fittingWAM( datanum, env, pout_v, pdataset)
-    return pout_vnp
+    return pout_vnp, dataset
 
 
 # Generated python wrapper for:
@@ -862,30 +877,31 @@ def fm_arraysize(n, kint, env):
 
 
 # Generated python wrapper for:
-#    int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* vv, struct fm_env* env)
-def generate_fm_minplus(num, n, kint, markov, option, K, vv, env):
-    trace( "int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* vv, struct fm_env* env)")
-    pvvnp, pvv = convert_py_float_to_cffi( vv)
-    yy = fm.py_generate_fm_minplus( num, n, kint, markov, option, K, pvv, env)
-    return yy
+#    int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* out_vv, struct fm_env* env)
+def generate_fm_minplus(num, n, kint, markov, option, K, env):
+    trace( "int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* out_vv, struct fm_env* env)")
+    len = fm.py_fm_arraysize(n, kint, env) * n
+    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( len)
+    yy = fm.py_generate_fm_minplus( num, n, kint, markov, option, K, pout_vv, env)
+    return yy, pout_vvnp
 
 
 # Generated python wrapper for:
-#    int py_generate_fm_2additive_convex(int num, int n,  double* vv)
-def generate_fm_2additive_convex(num, n, vv):
+#    int py_generate_fm_2additive_convex(int num, int n,  double* out_vv)
+def generate_fm_2additive_convex(num, n):
     trace( "int py_generate_fm_2additive_convex(int num, int n,  double* vv)")
-    pvvnp, pvv = convert_py_float_to_cffi( vv)
-    yy = fm.py_generate_fm_2additive_convex( num, n, pvv)
-    return yy
+    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( n)
+    yy = fm.py_generate_fm_2additive_convex( num, n, pout_vv)
+    return yy, pout_vvnp
 
 
 # Generated python wrapper for:
-#    int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* vv)
-def generate_fm_2additive_convex_withsomeindependent(num, n, vv):
+#    int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* out_vv)
+def generate_fm_2additive_convex_withsomeindependent(num, n):
     trace( "int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* vv)")
-    pvvnp, pvv = convert_py_float_to_cffi( vv)
-    yy = fm.py_generate_fm_2additive_convex_withsomeindependent( num, n, pvv)
-    return yy
+    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( n)
+    yy = fm.py_generate_fm_2additive_convex_withsomeindependent( num, n, pout_vv)
+    return yy, pout_vvnp
 
 
 # Generated python wrapper for:
