@@ -1,4 +1,5 @@
 import wrapper as pyw
+import sys
 
 r=3
 n=3
@@ -81,51 +82,95 @@ print( "equals: ", pnm)
 
 # Test wrapper for:
 #    double py_min_subset(double* x, int n, int_64 S)
-# pyw.min_subset(x, n, S)
-# not documented
+x = [0,0.3,0.5,0.6,0.7,0.8,0.85,0.9]
+n = len( x)
+S = 6
+min = pyw.min_subset( x, n, S)
+print( "x: ", x)
+print( "n: ", n)
+print( "S: ", S)
+print( "min: ", min)
+
 
 # Test wrapper for:
 #    double py_max_subset(double* x, int n, int_64 S)
 # pyw.max_subset(x, n, S)
-# not documented
+x = [0,0.3,0.5,0.6,0.7,0.8,0.85,0.9]
+n = len( x)
+S = 5
+max = pyw.max_subset( x, n, S)
+print( "x: ", x)
+print( "n: ", n)
+print( "S: ", S)
+print( "max: ", max)
 
 # Test wrapper for:
 #    double py_min_subsetC(double* x, int n, int_64 S, struct fm_env* env)
-# pyw.min_subsetC(x, n, S, env)
-# not documented
+x = [0,0.3,0.5]
+n = len( x)
+S = 3
+min = pyw.min_subsetC( x, n, S, env)
+print( "x: ", x)
+print( "n: ", n)
+print( "S: ", S)
+print( "min: ", min)
 
 # Test wrapper for:
 #    double py_max_subsetNegC(double* x, int n, int_64 S, struct fm_env* env)
-# pyw.max_subsetNegC(x, n, S, env)
-# not documented
-
+x = [0,0.3,0.5]
+n = len( x)
+S = 3
+max = pyw.max_subsetNegC( x, n, S, env)
+print( "x: ", x)
+print( "n: ", n)
+print( "S: ", S)
+print( "max: ", max)
 
 # Test wrapper for:
 #    int py_SizeArraykinteractive(int n, int k, struct fm_env* env)
-# pyw.SizeArraykinteractive(n, k, env)
-# not documented
-
+n = 3
+k = 1
+s = pyw.SizeArraykinteractive(n, k, env)
+print( "n: ", n)
+print( "k: ", k)
+print( "size: ", s)
 
 # Test wrapper for:
 #    int py_IsSubsetC(int i, int j, struct fm_env* env)
-# pyw.IsSubsetC(i, j, env)
-# not documented
+i = 2
+j = 1
+s = pyw.IsSubsetC(n, k, env)
+print( "i: ", i)
+print( "j: ", j)
+print( "size: ", s)
 
 # Test wrapper for:
 #    int py_IsElementC(int i, int j, struct fm_env* env)
-# pyw.IsElementC(i, j, env)
-# not documented
+i = 2
+j = 1
+s = pyw.IsElementC(n, k, env)
+print( "i: ", i)
+print( "j: ", j)
+print( "size: ", s)
 
 # Test wrapper for:
 #    void py_ExpandKinteractive2Bit(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize)
-# pyw.ExpandKinteractive2Bit(src, env, kint, arraysize)
-# not documented
-
+src = [0.0340916, 0.01109779, 0.07918582,0.7,1]
+kint = 1
+dest = pyw.ExpandKinteractive2Bit(src, env, kint)
+print( "src: ", src)
+print( "kint: ", kint)
+print( "dest: ", dest)
 
 # Test wrapper for:
-#    void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* VVC)
-# pyw.ExpandKinteractive2Bit_m(src, env, kint, arraysize, VVC)
-# not documented
+#    void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)
+src = [0.0340916, 0.01109779, 0.07918582,0.7,1]
+kint = 1
+dest, VVC = pyw.ExpandKinteractive2Bit_m(src, env, kint)
+print( "src: ", src)
+print( "kint: ", kint)
+print( "dest: ", dest)
+print( "VVC: ", VVC)
 
 # Test wrapper for:
 #    void py_Shapley(double* v, double* out_x, struct fm_env* env)
@@ -198,85 +243,178 @@ w = pyw.dualmMob(Mob, env)
 print( "Mob: ", Mob)
 print( "w: ", w)
 
-
 # Test wrapper for:
 #    double py_Entropy(double* v, struct fm_env* env)
-# pyw.Entropy(v, env)
-# not documented
-
+v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
+r = pyw.Entropy(v, env)
+print( "v: ", v)
+print( "r: ", r)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-# pyw.FuzzyMeasureFit(datanum, additive, env, dataset)
-# not documented
+datanum = 10
+additive = 2
+res, dataset = pyw.FuzzyMeasureFit(datanum, additive, env, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "dataset: ", dataset)
+print( "res: ", res)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-# pyw.FuzzyMeasureFitMob(datanum, additive, env, dataset)
-# not documented
+datanum = 10
+additive = 3
+res, dataset = pyw.FuzzyMeasureFitMob(datanum, additive, env, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "dataset: ", dataset)
+print( "res: ", res)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-# pyw.FuzzyMeasureFitKtolerant(datanum, additive, env, dataset)
-# not documented
-
+datanum = 10
+additive = 2
+res, dataset = pyw.FuzzyMeasureFitKtolerant(datanum, additive, env, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "dataset: ", dataset)
+print( "res: ", res)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-# pyw.FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset)
-# not documented
-
+datanum = 10
+additive = 2
+res, dataset = pyw.FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "dataset: ", dataset)
+print( "res: ", res)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
-# pyw.FuzzyMeasureFitLPKinteractive(datanum, additive, env, dataset, K)
-# not documented
-
+datanum = 10
+additive = 2
+K = [0.5]
+v, dataset = pyw.FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "K: ", K)
+print( "dataset: ", dataset)
+print( "v: ", v)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
-# pyw.FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, dataset, K)
-# not documented
-
+datanum = 10
+additive = 2
+K = [0.5]
+v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "K: ", K)
+print( "dataset: ", dataset)
+print( "v: ", v)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveAutoK(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters)
-# pyw.FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, dataset, K, maxiters)
-# not documented
-
+datanum = 10
+additive = 2
+K = [0.5]
+maxiters = [100]
+v, dataset = pyw.FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "K: ", K)
+print( "maxiters: ", maxiters)
+print( "dataset: ", dataset)
+print( "v: ", v)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveMarginal(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int submod)
-# pyw.FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env, dataset, K, submod)
-# not documented
-
+datanum = 10
+additive = 2
+K = [0.5]
+submod = 1
+v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env,  K, submod, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "submod: ", submod)
+print( "K: ", K)
+print( "dataset: ", dataset)
+print( "v: ", v)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)
-# pyw.FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, dataset, K, maxiters, submod)
-# not documented
+datanum = 10
+additive = 2
+K = [0.5]
+submod = 1
+v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "submod: ", submod)
+print( "K: ", K)
+print( "dataset: ", dataset)
+print( "v: ", v)
 
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
-# pyw.FuzzyMeasureFitLP(datanum, additive, env, dataset, options, indexlow, indexhihg, option1, orness)
-# documented, no example
+datanum = 10
+additive = 2
+options = [0]
+indexlow = [0, 0, 0]
+indexhihg = [1, 1, 1]
+option1 = [0]
+orness = [0.5]
+v, dataset = pyw.FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "indexlow: ", indexlow)
+print( "options: ", options)
+print( "indexhihg: ", indexhihg)
+print( "option1: ", option1)
+print( "orness: ", orness)
+print( "dataset: ", dataset)
+print( "v: ", v)
 
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLPMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
-# pyw.FuzzyMeasureFitLPMob(datanum, additive, env, dataset, options, indexlow, indexhihg, option1, orness)
-# documented, no example
-
+datanum = 10
+additive = 2
+options = [0]
+indexlow = [0, 0, 0]
+indexhihg = [1, 1, 1]
+option1 = [0]
+orness = [0.5]
+Mob, dataset = pyw.FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None)
+print( "datanum: ", datanum)
+print( "additive: ", additive)
+print( "indexlow: ", indexlow)
+print( "options: ", options)
+print( "indexhihg: ", indexhihg)
+print( "option1: ", option1)
+print( "orness: ", orness)
+print( "dataset: ", dataset)
+print( "Mob: ", Mob)
 
 # Test wrapper for:
 #    void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)
-# pyw.fittingOWA(datanum, env, dataset)
 # documented, no example
+datanum = 10
+v , dataset = pyw.fittingOWA(datanum, env, dataset = None)
+print( "datanum: ", datanum)
+print( "dataset: ", dataset)
+print( "v: ", v)
 
 # Test wrapper for:
 #    void py_fittingWAM(int datanum, struct fm_env* env, double* out_v, double* dataset)
-# pyw.fittingWAM(datanum, env, dataset)
 # documented, no example
+datanum = 10
+atanum = 10
+v , dataset = pyw.fittingWAM(datanum, env, dataset = None)
+print( "datanum: ", datanum)
+print( "dataset: ", dataset)
+print( "v: ", v)
 
 # Test wrapper for:
 #    void py_Interaction(double* out_Mob, double* v, struct fm_env* env)
@@ -308,18 +446,27 @@ print( "w: ", w)
 
 # Test wrapper for:
 #    void py_BipartitionShapleyIndex(double* v, double* out_w, struct fm_env* env)
-# pyw.BipartitionShapleyIndex(v, env)
-# not documented
+# not documented in R or Python user guide
+v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1]
+s = pyw.BipartitionShapleyIndex(v, env)
+print( "v: ", v)
+print( "s: ", s)
 
 # Test wrapper for:
 #    void py_BipartitionBanzhafIndex(double* v, double* out_w, struct fm_env* env)
-# pyw.BipartitionBanzhafIndex(v, env)
-# not documented
+# not documented in R or Python user guide
+v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1]
+s = pyw.BipartitionBanzhafIndex(v, env)
+print( "v: ", v)
+print( "s: ", s)
 
 # Test wrapper for:
 #    void py_BNonadditivityIndexMob(double* Mob, double* out_w, struct fm_env* env)
-# pyw.BNonadditivityIndexMob(Mob, env)
-# not documented
+# not documented in R or Python user guide
+Mob = [0.2, 0.3, 0.5, -0.2, 0.4, 0.1]
+s = pyw.BNonadditivityIndexMob(Mob, env)
+print( "v: ", v)
+print( "s: ", s)
 
 # Test wrapper for:
 #    void py_NonadditivityIndex(double* v, double* out_w, struct fm_env* env)
@@ -476,13 +623,23 @@ print( "Mob: ", Mob)
 
 # Test wrapper for:
 #    double py_OWA(double* x, double* v, struct fm_env* env)
-# pyw.OWA(x, v, env)
-# not documented
+# not documented in R or Python user guide
+x = [0.3, 0.4, 0.8, 0.2]   # inputs
+w = [0.4, 0.35 ,0.2 ,0.05] # OWA weights
+res = pyw.OWA(x, v, env)
+print( "v: ", v)
+print( "w: ", w)
+print( "res: ", res)
 
 # Test wrapper for:
 #    double py_WAM(double* x, double* v, struct fm_env* env)
-# pyw.WAM(x, v, env)
-# not documented
+# not documented in R or Python user guide
+x = [0.3, 0.4, 0.8, 0.2]   # inputs
+w = [0.4, 0.35 ,0.2 ,0.05] # OWA weights
+res = pyw.WAM(x, v, env)
+print( "v: ", v)
+print( "w: ", w)
+print( "res: ", res)
 
 # Test wrapper for:
 #    void py_Zeta(double* Mob, double* out_v, struct fm_env* env)
@@ -538,133 +695,165 @@ print( "n: ", n)
 print( "length: ", l)
 
 # Test wrapper for:
-#    int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* vv, struct fm_env* env)
-# pyw.generate_fm_minplus(num, n, kint, markov, option, K, vv, env)
-# not documented
+#    int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* out_vv, struct fm_env* env)
+# pyw.generate_fm_minplus(num, n, kint, markov, option, K, out_vv, env)
+# not documented in R or Python user guide
+num = 10
+n = 6
+kint = 3
+markov = 1000
+option = 0
+K = 0.7
+array_size = 0
+vv = []
+# array_size, vv = pyw.generate_fm_minplus(num, n, kint, markov, option, K, env)
+print( "num: ", num)
+print( "n: ", n)
+print( "kint: ", kint)
+print( "markov: ", markov)
+print( "option: ", option)
+print( "K: ", K)
+print( "array_size: ", array_size)
+print( "vv: ", vv)
 
 # Test wrapper for:
-#    int py_generate_fm_2additive_convex(int num, int n,  double* vv)
-# pyw.generate_fm_2additive_convex(num, n, vv)
-# not documented
+#    int py_generate_fm_2additive_convex(int num, int n,  double* out_vv)
+# not documented in R or Python user guide
+num = 10
+n = 6
+# array_size, vv = pyw.generate_fm_2additive_convex(num, n)
+print( "num: ", num)
+print( "n: ", n)
+print( "array_size: ", array_size)
+print( "vv: ", vv)
 
 # Test wrapper for:
-#    int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* vv)
-# pyw.generate_fm_2additive_convex_withsomeindependent(num, n, vv)
-# not documented
+#    int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* out_vv)
+# 
+# not documented in R or Python user guide
+num = 10
+n = 6
+# array_size, vv = pyw.generate_fm_2additive_convex_withsomeindependent(num, n)
+print( "num: ", num)
+print( "n: ", n)
+print( "array_size: ", array_size)
+print( "vv: ", vv)
+
+sys.exit()
 
 # Test wrapper for:
 #    void py_prepare_fm_sparse(int n, int tupsize, int* tuples, struct fm_env_sparse* out_env)
 # pyw.prepare_fm_sparse(n, tupsize, tuples, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_tuple_cardinality_sparse(int i, struct fm_env_sparse* env)
 # pyw.tuple_cardinality_sparse(i, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_get_num_tuples(struct fm_env_sparse* env)
 # pyw.get_num_tuples(env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_get_sizearray_tuples(struct fm_env_sparse* env)
 # pyw.get_sizearray_tuples(env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_is_inset_sparse(int A, int card, int i, struct fm_env_sparse* env)
 # pyw.is_inset_sparse(A, card, i, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_is_subset_sparse(int A, int cardA, int B, int cardB, struct fm_env_sparse* env)
 # pyw.is_subset_sparse(A, cardA, B, cardB, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    double py_min_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
 # pyw.min_subset_sparse(x, n, S, cardS, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    double py_max_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
 # pyw.max_subset_sparse(x, n, S, cardS, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)
 # pyw.ChoquetMob_sparse(x, n, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_ShapleyMob_sparse(double* v, int n, struct fm_env_sparse* out_env)
 # pyw.ShapleyMob_sparse(v, n, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_BanzhafMob_sparse(double* v, int n, struct fm_env_sparse* out_env)
 # pyw.BanzhafMob_sparse(v, n, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* out_env)
 # pyw.populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* out_env)
 # pyw.add_pair_sparse(i, j, v, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* out_env)
 # pyw.add_tuple_sparse(tupsize, tuple, v, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* out_env)
 # pyw.populate_fm_2add_sparse_from2add(n, v, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_expand_2add_full(double* v, struct fm_env_sparse* out_env)
 # pyw.expand_2add_full(v, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_expand_sparse_full(double* v, struct fm_env_sparse* out_env)
 # pyw.expand_sparse_full(v, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_sparse_get_singletons(int n, double* v, struct fm_env_sparse* out_env)
 # pyw.sparse_get_singletons(n, v, out_env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_sparse_get_pairs(int* pairs, double* v, struct fm_env_sparse* env)
 # pyw.sparse_get_pairs(pairs, v, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_sparse_get_tuples(int* tuples, double* v, struct fm_env_sparse* env)
 # pyw.sparse_get_tuples(tuples, v, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int   py_generate_fm_2additive_convex_sparse(int n, struct fm_env_sparse* env)
 # pyw.generate_fm_2additive_convex_sparse(n, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int   py_generate_fm_kadditive_convex_sparse(int n, int k, int nonzero, struct fm_env_sparse* env)
 # pyw.generate_fm_kadditive_convex_sparse(n, k, nonzero, env)
-# not documented
+# not documented in R or Python user guide
 
 # Test wrapper for:
 #    void py_Nonmodularityindex_sparse(double* w, int n, struct fm_env_sparse* out_env)
 # pyw.Nonmodularityindex_sparse(w, n, out_env)
-# not documented
+# not documented in R or Python user guide
 
 pyw.fm_free( env);
